<?php

// Exit if accessed directly
if (!defined('ABSPATH'))
    exit;

if (!class_exists('EM_Shortcodes')) {

    class EM_Shortcodes {

        private static $instance = null;
        public $codes = array('em_events' => 'load_events', 'em_performers' => 'load_performers', 'em_event_types' => 'load_event_types',
            'em_sites' => 'load_venues', 'em_booking' => "load_booking", 'em_profile' => "load_profile", 'em_event' => 'load_single_event',
            'em_event_type' => 'load_single_event_type', 'em_performer' => 'load_single_performer', 'em_event_site' => 'load_single_venue');

        public static function get_instance() {
            if (self::$instance === null) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        private function __construct() {
            $this->add_shortcodes();
        }

        private function add_shortcodes() {
            foreach ((array) $this->codes as $code => $function) {
                add_shortcode($code, array($this, $function));
            }
        }

        public function load_profile($atts) {
            $profile_shortcode = apply_filters('ep_load_profile',false,$atts);
            if(empty($profile_shortcode)){
                ob_start();
                include('templates/user_profile.php');
                return ob_get_clean();
            }
            else{
                return do_shortcode($profile_shortcode);
            }
        }

        public function load_single_event($atts) {
            ob_start();
            $event_id = absint($atts['id']);
            $post = get_post($event_id);
            if (!empty($post)) {
                if ($post->post_type == "em_event" && $post->post_status != "trash") {
                    $event_id = $post->ID;
                    include('templates/event.php');
                }
            }
            return ob_get_clean();
        }

        public function load_events($atts) {
            ob_start();
            $event_id = absint(event_m_get_param('event'));

            if (!empty($event_id)) {
                $post = get_post($event_id);
                if (!empty($post) && $post->post_type == "em_event" && $post->post_status != "trash")
                    include('templates/event.php');
            }
            else {
                include('templates/events.php');
            }
            return ob_get_clean();
        }

        public function load_single_performer($atts) {
            ob_start();
            $performer_id = absint($atts['id']);
            $post = get_post($performer_id);

            if (empty($post) || $post->post_type != 'em_performer' || $post->post_status == 'trash') {
                _e('No such performer found', 'eventprime-event-calendar-management');
                return ob_get_clean();
            }

            include('templates/single-performer.php');
            return ob_get_clean();
        }

        public function load_performers($atts) {
            ob_start();
            $performer_id = absint(event_m_get_param('performer'));
            if (!empty($performer_id)) {
                $post = get_post($performer_id);
                if (!empty($post) && $post->post_type == "em_performer" && $post->post_status != "trash")
                    include('templates/single-performer.php');
            } else
                include('templates/performers.php');
            return ob_get_clean();
        }

        public function load_venues($atts) {
            ob_start();
            include('templates/venues.php');
            return ob_get_clean();
        }

        public function load_single_venue($atts) {
            ob_start();
            $venue_page_id = em_global_settings('venues_page');
            $venue_id = absint($atts['id']);
            $service = EventM_Factory::get_service('EventM_Venue_Service');
            $venue = $service->load_model_from_db($venue_id);
            if (empty($venue->id)) {
                _e('No such site exists.', 'eventprime-event-calendar-management');
            } else {
                include_once 'templates/venue.php';
            }
            return ob_get_clean();
        }

        public function load_booking() {
            ob_start();
            if (is_user_logged_in()) { // Removing all the temporary bookings for current user
                $booking_service = EventM_Factory::get_service('EventM_Booking_Service');
                $user = wp_get_current_user();
                $booking_service->remove_tmp_bookings_for_user($user->ID);
            }
            include('templates/booking.php');
            return ob_get_clean();
        }

        public function load_event_types($atts) {
            ob_start();
            include('templates/event_types.php');
            return ob_get_clean();
        }

        public function load_single_event_type($atts) {
            ob_start();
            $type_id = absint($atts['id']);

            $tmp = get_term($type_id, EM_EVENT_TYPE_TAX);
            if (is_wp_error($tmp) || empty($tmp)) {
                _e('No such Event Type exists', 'eventprime-event-calendar-management');
                return ob_get_clean();
            }

            $event_service = EventM_Factory::get_service('EventM_Service');
            // Creating term object for template
            $type = new stdClass();
            $type->name = $tmp->name;
            $type->id = $tmp->term_id;
            $type->count = $event_service->event_count_by_type($type->id);
            $type->color = em_get_term_meta($type->id, 'color', true);


            include('templates/event_type.php');
            return ob_get_clean();
        }

    }

}

EM_Shortcodes::get_instance();
