<?php
if(!defined('ABSPATH')) exit;

/**
 * Esacaping request parameter
 * string paramete_key.
 *
 * @return string (Parameter Value)
 */
function event_m_get_param($param = null,$secure = false) {
    $postdata = file_get_contents("php://input");
    $request = json_decode($postdata);
    $null_return = null;

    if ($request !== null)
        $_POST = (array) $request;

    if ($param && isset($_POST[$param]) && is_array($_POST[$param])) {
        return $_POST[$param];
    }

    if ($param) {
        if ($secure)
            $value = (!empty($_POST[$param]) ? trim(esc_sql($_POST[$param])) : $null_return);
        else {
            $value = (!empty($_POST[$param]) ? trim(esc_sql($_POST[$param])) : (!empty($_GET[$param]) ? $_GET[$param] : $null_return ));
        }

        if(!is_array($value)){
           $value= stripslashes($value);
        }
        return $value;
    } else {
        $params = array();
        foreach ($_POST as $key => $param) {
            $params[trim(esc_sql($key))] = (!empty($_POST[$key]) ? trim(esc_sql($_POST[$key])) : $null_return );
        }
        if (!$secure) {
            foreach ($_GET as $key => $param) {
                $key = trim(esc_sql($key));
                if (!isset($params[$key])) { // if there is no key or it's a null value
                    $params[trim(esc_sql($key))] = (!empty($_GET[$key]) ? trim(esc_sql($_GET[$key])) : $null_return );
                }
            }
        }

        return stripslashes($params);
    }
}

function em_time($datetime) {
    if (empty($datetime))
        return;
    return strtotime($datetime);
}

function em_timestamp($str_date,$format='m/d/Y H:i'){
    $date=DateTime::createFromFormat($format,$str_date);
    if(empty($date))
        return false;
    return $date->getTimestamp();
}
/*
 * Return time in H:i format from timestamp
 */

function em_get_time($datetime) {
    return date('H:i', $datetime);
}

function em_showDateTime($datetime, $time = true, $format = null) {
    if (empty($format))
        $format = get_option('date_format');

    if (empty($datetime))
        return;
    if ($time)
        $format .= ' H:i';
    return date($format, $datetime);
}

/**
 * Function to get global settings data
 * Possible meta options: gmap_api_key
 */
function em_global_settings($meta = null) {
    // Load global setting array from options table
    $global_options = get_option(EM_GLOBAL_SETTINGS);

    // Check if option exists 
    if (!empty($global_options)) {
        if ($meta !== null) {
            if (array_key_exists($meta, $global_options)) {
                return $global_options[$meta];
            } else {
                // Option does not exists
                return false;
            }
        }
        return $global_options;
    }
    return false;
}

function em_check_event_status() {
    $event_service = EventM_Factory::get_service('EventM_Service');
    $event_service->update_past_event_status();
}

function em_delete_tmp_bookings() {
    $booking_service = EventM_Factory::get_service('EventM_Booking_Service');
    $booking_service->remove_all_tmp_bookings();
}

function em_get_attached_posts($id, $tax_type) {
    $args = array(
        'post_type' => EM_EVENT_POST_TYPE,
        'numberposts' => -1,
        'post_status' => 'any',
        'tax_query' => array(
            array(
                'taxonomy' => $tax_type,
                'field' => 'term_id',
                'terms' => $id
            )
        )
    );

    $events = get_posts($args);
    return $events;
}

function em_get_post_meta($post_id, $key = '', $single = false, $numeric = false) {
    if (!empty($key))
        $key = "em_" . $key;

    return get_post_meta($post_id, $key, $single);
}

function em_update_post_meta($post_id, $meta_key, $meta_value) {
    $meta_key = "em_" . $meta_key;
    update_post_meta($post_id, $meta_key, $meta_value);
}

function em_get_term_meta($term_id, $key = '', $single = false) {
    if (!empty($key)){
        $key = "em_" . $key;
        return get_term_meta($term_id, $key, $single);
    }
    return get_term_meta($term_id,$key, $single);    
    
    
}

function em_update_term_meta($term_id, $meta_key, $meta_value) {
    $meta_key = "em_" . $meta_key;
    update_term_meta($term_id, $meta_key, $meta_value);
}

function em_append_meta_key($key) {
    $keys = array();
    if (is_array($key)) {
        foreach ($key as $k) {
            $keys[] = "em_" . $k;
        }
        return $keys;
    } else
        return "em_" . $key;
}

function em_event_seating_capcity($event_id) {
    $capacity = (int) em_get_post_meta($event_id, 'seating_capacity', true);
    if (!empty($capacity))
        return $capacity;
    $venues = wp_get_object_terms($event_id, EM_EVENT_VENUE_TAX);
    if (!empty($venues)){
        $type = em_get_term_meta($venues[0]->term_id, 'type', true);
        if ($type == "standings")
            return 0;
        if (empty($venues))
            return 0;
        $venue = $venues[0];
        $capacity = (int) em_get_term_meta($venue->term_id, 'seating_capacity', true);
        return $capacity;
    }
    else{
        return 0;
    }
}

function is_registration_magic_active() {
    if (defined("REGMAGIC_BASIC") || defined("REGMAGIC_GOLD"))
        return true;
    else
        return false;
}


// Returns true if both dates are equal
function em_compare_event_dates($event_id) {
    $start_date = em_showDateTime(em_get_post_meta($event_id, 'start_date', true), false);
    $end_date = em_showDateTime(em_get_post_meta($event_id, 'end_date', true), false);

    if (strtotime($start_date) == strtotime($end_date))
        return true;
    else
        return false;
}

function em_is_event_expired($event_id) {
    // Check event status
    $event = get_post($event_id);
    if ($event->post_status == "expired")
        return true;

    return false;
}

function em_set_mail_content_type_html($content_type) {
    $content_type = 'text/html';
    return $content_type;
}

function em_set_mail_from($original_email_address) {
    return get_option('admin_email');
}

function em_set_mail_from_name($original_from_address) {
    return get_option('blogname');
}

function em_rm_custom_data($user_id) {
    $current_user = get_user_by("ID", $user_id);
    $data = new stdClass();
    $data->is_user = true;
    $data->user = $current_user;
    $rm_Service = new RM_Services();
    $data->custom_fields = $rm_Service->get_custom_fields($current_user->user_email);

    if ($data->user->first_name) {
        ?>
        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('FIELD_TYPE_FNAME'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->first_name; ?></span>
        </div>
        <?php
    }
    if ($data->user->last_name) {
        ?>

        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('FIELD_TYPE_LNAME'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->last_name; ?></span>
        </div>
        <?php
    }
    if ($data->user->description) {
        ?>

        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('LABEL_BIO'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->description; ?></span>
        </div>
        <?php
    }
    if ($data->user->user_email) {
        ?>

        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('LABEL_EMAIL'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->user_email; ?></span>
        </div>
        <?php
    }
    if ($data->user->sec_email) {
        ?>

        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('LABEL_SECEMAIL'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->sec_email; ?></span>
        </div>
        <?php
    }
    if ($data->user->nickname) {
        ?>

        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('FIELD_TYPE_NICKNAME'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->nickname; ?></span>
        </div>
        <?php
    }
    if ($data->user->user_url) {
        ?>

        <div class="em-booking-row">
            <span class="em-booking-label"><?php echo RM_UI_Strings::get('FIELD_TYPE_WEBSITE'); ?>:</span>
            <span class="em-booking-detail"><?php echo $data->user->user_url; ?></span>
        </div>
        <?php
    }

    if (is_array($data->custom_fields) || is_object($data->custom_fields))
        foreach ($data->custom_fields as $field_id => $sub) {
            $key = $sub->label;
            $meta = $sub->value;
            $sub_original = $sub;
            if (!isset($sub->type)) {
                $sub->type = '';
            }

            $meta = RM_Utilities::strip_slash_array(maybe_unserialize($meta));
            ?>
            <div class="em-booking-row">

                <span class="em-booking-label"><?php echo $key; ?></span>
                <span class="em-booking-detail">
            <?php
            if (is_array($meta) || is_object($meta)) {
                if (isset($meta['rm_field_type']) && $meta['rm_field_type'] == 'File') {
                    unset($meta['rm_field_type']);

                    foreach ($meta as $sub) {

                        $att_path = get_attached_file($sub);
                        $att_url = wp_get_attachment_url($sub);
                        ?>
                                <div class="rm-submission-attachment">
                                <?php echo wp_get_attachment_link($sub, 'thumbnail', false, true, false); ?>
                                    <div class="rm-submission-attachment-field"><?php echo basename($att_path); ?></div>
                                    <div class="rm-submission-attachment-field"><a href="<?php echo $att_url; ?>"><?php echo RM_UI_Strings::get('LABEL_DOWNLOAD'); ?></a></div>
                                </div>

                        <?php
                    }
                } elseif (isset($meta['rm_field_type']) && $meta['rm_field_type'] == 'Address') {
                    $sub = $meta['original'] . '<br/>';
                    if (count($meta) === 8) {
                        $sub .= '<b>Street Address</b> : ' . $meta['st_number'] . ', ' . $meta['st_route'] . '<br/>';
                        $sub .= '<b>City</b> : ' . $meta['city'] . '<br/>';
                        $sub .= '<b>State</b> : ' . $meta['state'] . '<br/>';
                        $sub .= '<b>Zip code</b> : ' . $meta['zip'] . '<br/>';
                        $sub .= '<b>Country</b> : ' . $meta['country'];
                    }
                    echo $sub;
                } elseif ($sub->type == 'Time') {
                    echo $meta['time'] . ", Timezone: " . $meta['timezone'];
                } else {
                    $sub = implode(', ', $meta);
                    echo $sub;
                }
            } else {
                if ($sub->type == 'Rating') {
                    echo RM_Utilities::enqueue_external_scripts('script_rm_rating', RM_BASE_URL . 'public/js/rating3/jquery.rateit.js');
                    echo '<div class="rateit" id="rateit5" data-rateit-min="0" data-rateit-max="5" data-rateit-value="' . $meta . '" data-rateit-ispreset="true" data-rateit-readonly="true"></div>';
                } else
                    echo $meta;
            }
            ?>
                </span>
            </div>
            <?php
        }
}

function em_datetime_diff($start, $end) {
    $start_date_time = new DateTime();
    $start_date_time->setTimestamp($start);
    $end_date_time = new DateTime();
    $end_date_time->setTimestamp($end);
    $interval = $end_date_time->diff($start_date_time);
    return $interval;
}

function em_get_mail_confirm_content($order_id) {
    $booking_service = EventM_Factory::get_service('EventM_Booking_Service');
    $event_detail = $booking_service->get_event_by_booking($order_id);
    $data = (array) $event_detail;
    return $data;
}

function em_localize_map_info() {
    $gmap_api_key = em_global_settings('gmap_api_key');
    $local_objects = array();

    if ($gmap_api_key):
        $local_objects['gmap_uri'] = 'https://maps.googleapis.com/maps/api/js?key=' . $gmap_api_key . '&libraries=places';
    else:
        $local_objects['gmap_uri'] = false;
    endif;
    wp_localize_script('em-google-map', "em_map_info", $local_objects);
    wp_enqueue_script('em-google-map');
}

/*
 * Convert an associative array into key,label objects for dropdown fields
 */
function em_array_to_options($data = array()) {
    $options = array();
    foreach ($data as $key => $value) {
        $option = new stdClass();
        if (is_numeric($key))
            $option->key = $value;
        else
            $option->key = $key;

        $option->label = $value;
        $options[] = $option;
    }

    return $options;
}

function em_array_sort_by_date($a, $b) {
    return strtotime($a) > strtotime($b);
}

function get_payment_log_info($booking_id) {
    $payment_log = maybe_unserialize(em_get_post_meta($booking_id, 'payment_log', true));
    $currency_symbol = "";
    $currency_code = em_global_settings('currency');

    if (isset($payment_log['payment_gateway']) && ($payment_log['payment_gateway'] == 'paypal' )){
        $currency_code = $payment_log['mc_currency'];
    }
    elseif(isset($payment_log['payment_gateway']) && $payment_log['payment_gateway'] == 'stripe'){
        $currency_code = $payment_log['currency'];
    }

    if ($currency_code){
        $all_currency_symbols = EventM_Constants::get_currency_symbol();
        $currency_symbol = $all_currency_symbols[$currency_code];
    }
    else
    {
        $currency_symbol = EM_DEFAULT_CURRENCY;
    }
    return $currency_symbol;
}

function em_redirect_event_posts() {
    $postID = url_to_postid($_SERVER['REQUEST_URI']);
    $post = get_post($postID);
    $redirect_url = '';
    if (!empty($post) && $post->post_status != "trash") {
        $post_type = get_post_type($postID);
        if ($post_type == 'em_event') {
            $page_url = get_permalink(em_global_settings("events_page"));
            $redirect_url = add_query_arg("event", $postID, $page_url);
        } elseif ($post_type == 'em_performer') {
            $page_url = get_permalink(em_global_settings("performers_page"));
            $redirect_url = add_query_arg("performer", $postID, $page_url);
        } else
            return;

        wp_redirect($redirect_url);
        exit;
    }
}

function em_check_required_pages() {
    $notices = '';
    $pages = array(
        "events_page" => array("Event List", "[em_events]"),
        "venues_page" => array("Site & Location", "[em_sites]"),
        "booking_page" => array("Booking", "[em_booking]"),
        "profile_page" => array("User Profile", "[em_profile]"),
        "performers_page" => array("Performer List", "[em_performers]")
    );
    foreach ($pages as $key => $value) {
        $page_id = em_global_settings($key);
        $post = get_post($page_id);
        if(empty($post)){
            $notices .= '<p> For ' . $value[0] . ' use ' . $value[1] . ' shortcode</p>';
                continue;
        }
        $short_code_exists = strpos($post->post_content, $value[1]);
        if (empty($post) || $post->post_status == "trash" || $short_code_exists === false) {
            $notices .= '<p> For ' . $value[0] . ' use ' . $value[1] . ' shortcode</p>';
        }
    }

    if (!empty($notices)) 
    {
        echo '<div class="notice notice-success is-dismissible">EventPrime: It seems all the required pages are not configured.' . $notices .
        '<b>Note*: Once you have pasted all the shortcodes inside corresponding pages, you can configure the default pages in EventPrime Global Settings->Default Pages. </b>' .
        '</div>';
    }
}

function em_posts_order_by($orderby_statement) {
    return 'post_status DESC,' . $orderby_statement;
}

function em_add_editor($editor_id, $content = '') {
    wp_editor($content, $editor_id);
}

function em_currency_symbol() {
    $setting_service = EventM_Factory::get_service('EventM_Setting_Service');
    $setting = $setting_service->load_model_from_db();
    $all_currency_symbols = EventM_Constants::get_currency_symbol();
    $currency_symbol = $all_currency_symbols[$setting->currency];
    return $currency_symbol;
}

function em_global_js_strings() {
    return array(
        'date_format' => 'yy-mm-dd',
        'ajax_url' => admin_url('admin-ajax.php')
    );
}

function em_is_user_admin() {
    if (current_user_can('manage_options')) {
        return true;
    }
    return false;
}

function em_manager_navs(){
    $manager_navs= array(
                        array('key'=>'event_magic','label'=>__('Events Manager','eventprime-event-calendar-management')),
                        array('key'=>'em_event_types','label'=>__('Event Type Manager','eventprime-event-calendar-management')),
                        array('key'=>'em_venues','label'=>__('Event Site Manager','eventprime-event-calendar-management')),
                        array('key'=>'em_performers','label'=>__('Performers Manager','eventprime-event-calendar-management'))    
                    );
    $manager_navs= apply_filters('event_magic_manager_navs',$manager_navs);
    return $manager_navs;
}

function em_dates_from_range($start, $end) 
{
    $array= array();    
    $interval = new DateInterval('P1D');
    
    $realEnd = new DateTime($end);
    $realEnd->add($interval);

    $period = new DatePeriod(
         new DateTime($start),
         $interval,
         $realEnd
    );

    foreach($period as $date) { 
        $array[] = $date->format('Y-m-d'); 
    }

    return $array;
}

function em_is_ssl(){
    return is_ssl();
}

function em_is_admin(){
    if(current_user_can('manage_options')){
        return true;
    }
    return false;
}

function em_get_converted_price_in_cent($price,$currency){
    if(em_is_price_conversion_req_for_stripe($currency))
        return $price*100;
    return $price;
}
    
function convert_fr($currency,$price){
    if(em_is_price_conversion_req_for_stripe($currency))
        return $price/100;
    return $price;
}
    
function em_is_price_conversion_req_for_stripe($currency){
    $currency= strtoupper($currency);
        switch($currency)
        {
            case 'BIF':
            case 'DJF':
            case 'JPY':
            case 'KRW':
            case 'PYG':
            case 'VND':
            case 'XAF':
            case 'XPF':
            case 'CLP':
            case 'GNF':
            case 'KMF':
            case 'MGA':
            case 'RWF':
            case 'VUV':
            case 'XOF':
                return false;
            default:
                return true;
        }
        return false;
}
