<?php

if (!defined('ABSPATH')) {
    exit;
}

class EventTypeM_Service {

    private $dao;
    private static $instance = null;
    
    private function __construct() {
        $this->dao = new EventM_Event_Type_DAO();
    }
    
    public static function get_instance()
    {   
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /*
     * Load Add/Edit page for REST 
     */
    public function load_edit_page() {
        $id = event_m_get_param('term_id');
        $event_type = $this->load_model_from_db($id);
        $event_type->age_groups = $this->age_dropdown($event_type->age_group);
        return $event_type;
    }

    /*
     * Load List page for REST 
     */

    public function load_list_page() {
        $response = new stdClass();
        $response->terms = array();
        $args= array('hide_empty' => false,
                    'offset' =>(absint(event_m_get_param('paged')) - 1) * EM_PAGINATION_LIMIT,
                    'number' => EM_PAGINATION_LIMIT, 'orderby' => 'term_id', 'order' => 'DESC');
        $response->terms = $this->get_types($args);
        $terms_count = wp_count_terms(EM_EVENT_TYPE_TAX, array('hide_empty' => false));
        if ($terms_count>0)
            $response->total_count = range(1, $terms_count);
        $response->pagination_limit = EM_PAGINATION_LIMIT;
        $response->tax_type = EM_EVENT_TYPE_TAX;
        return $response;
    }

    /*
     * Saving Event Type (Term) 
     */
    public function save($model) {
        // Check if user added any custom age group 
        $custom_age_group = isset($model->custom_group) ? $model->custom_group : '';
        if (!empty($custom_age_group)) {
            $model->custom_group = $custom_age_group;
        }
        $type = $this->dao->save($model);
        return $type;
    }

    public function age_dropdown($age_group) {
        $age_groups = array(
            "all" => __('All', 'eventprime-event-calendar-management'),
            "parental_guidance" => __('All ages but parental guidance', 'eventprime-event-calendar-management'),
            "custom_group" => __('Custom Age', 'eventprime-event-calendar-management'),
        );
        if (!in_array($age_group, array("all", "parental_guidance", "custom_group")))
            $age_groups[$age_group] = $age_group;

        return em_array_to_options($age_groups);
    }

    public function load_model_from_db($id) {
        return $this->dao->get($id);
    }

    public function map_request_to_model($id, $model = null) {
        $type = new EventM_Event_Type_Model($id);
        $data = (array) $model;

        if (!empty($data) && is_array($data)) {
            foreach ($data as $key => $val) {
                if(property_exists($type, $key)){
                    $type->{$key}= $val;
                }
            }
        }
        return $type;
    }

    public function validate($model) {
        $errors= array();
        $term = term_exists($model->name, EM_EVENT_TYPE_TAX);
        if (!empty($term) && isset($term['term_id']) && $term['term_id'] != $model->id) {
            $errors[]= __('Please use different name.','eventprime-event-calendar-management');
        }
        return $errors;
    }

    public function count($args) {
        $types = $this->dao->get_all($args);
        return count($types);
    }

    public function get_types($args = array()) {
        $types = $this->dao->get_all($args);
        return $types;
    }

}

?>
