<?php

if (!defined( 'ABSPATH')){
    exit;
}

class EventM_Performer_Service {
    
    private $dao;
    private static $instance = null;
    
    private function __construct() {
        $this->dao= new EventM_Performer_DAO();
    }
    
    public static function get_instance()
    {   
        if (self::$instance === null) {
            self::$instance = new self();
        }

        return self::$instance;
    }
    
    /*
     * Load Add/Edit page for REST 
    */
    public function load_edit_page()
    {
        $id = event_m_get_param('post_id');
        $performer= $this->load_model_from_db($id);
        if(empty($performer))
        {
            wp_send_json_error();
        }
        $performer->types=  $this->get_types();
        $performer->feature_image= $this->get_image($id);
        return $performer;
    }
    
    /*
     * Load List page for REST 
     */
    public function load_list_page()
    {
        $response= new stdClass();
        $response->posts= array();
         
        // Get all the performers (posts)
        $args = array(
            'posts_per_page' => EM_PAGINATION_LIMIT,
            'offset' => ((int) event_m_get_param('paged')-1) * EM_PAGINATION_LIMIT,
            'post_type' => EM_PERFORMER_POST_TYPE,
            'post_status' => 'publish');
        $performers = $this->get_all($args);
       
        // Couting number of events for the performer
        $event_count= array();
        $event_service = EventM_Factory::get_service('EventM_Service');
        $events= $event_service->get_all();
        foreach($events as $event){
            if(!empty($event->performer) && !empty($event->enable_performer)){
                foreach($event->performer as $performer_id){
                    if(isset($event_count[$performer_id])){
                        $event_count[$performer_id] +=1;
                    }
                    else{
                        $event_count[$performer_id]= 1;
                    }
                }
            }
        }
        
        foreach($performers as $performer){
           $performer->cover_image_url= $this->get_image($performer->id,'large');
           if(isset($event_count[$performer->id])){
               $performer->events= $event_count[$performer->id];
           } else{
               $performer->events=0;
           }
           $response->posts[]= $performer;
        }
        
        $post_count_obj = wp_count_posts($this->dao->post_type);
        $post_count= $post_count_obj->publish;
        $response->total_posts= range(1,$post_count);
        $response->pagination_limit= EM_PAGINATION_LIMIT;
        return $response;
    }
    
    public function save($model)
    {
       $performer= $this->dao->save($model);
       if(!empty($performer->feature_image_id)){
           $this->set_image($performer->id,$performer->feature_image_id);
       }
       return $performer;
    }

    public function get_upcoming_events(){
        $event_service= EventM_Factory::get_service('EventM_Service');
        $events= $event_service->get_upcoming_events();
        return $events;
    }
    
    public function load_model_from_db($id)
    {   
        return $this->dao->get($id);
    }
    
    public function map_request_to_model($id,$model=null)
    {  
        $performer= new EventM_Performer_Model($id);
        $data= (array) $model;
        
        if(!empty($data) && is_array($data))
        {
            foreach($data as $key=>$val)
            {
                if (property_exists($performer,$key)) {
                    $performer->{$key}= $val;
                }
            }
        }
        return $performer;
    }
    
    public function get_types()
    {
        $types= array('person'=>__('Person', 'eventprime-event-calendar-management'),
                      'group'=>__('Group', 'eventprime-event-calendar-management'));
        return em_array_to_options($types);
    }
    
    public function get_image($id,$size='thumbnail')
    {
       $img= wp_get_attachment_image_src(get_post_thumbnail_id($id),$size);
       if(!empty($img))
         return $img[0];
       return null;
    }
    
    public function set_image($id,$attach_id)
    {  
        if(!empty($attach_id)){
            $this->dao->set_thumbnail($id, $attach_id);
        }
    }
    
    public function get_all($args= array()){
       $performers=  $this->dao->get_all($args);
       return $performers;
    }
    
    public function count($args= array()){
        $performers=  $this->get_all($args);
        return count($performers);
    }
}
