<?php

if (!defined('ABSPATH')) {
    exit;
}

class EventM_User_Service {

    private $dao;
    private static $instance = null;
    
    private function __construct() {}
    
    public static function get_instance()
    {   
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    public function register_user() {
        $user_data = new stdClass();
        $response = new stdClass();
        $user_data->email = sanitize_email(event_m_get_param("email", true));
        $user_data->password = wp_generate_password(5);

        if (!$this->verify_user($user_data->email)) {
            $user_id = wp_create_user($user_data->email, $user_data->password, $user_data->email);
            if (!is_wp_error($user_id)) {
                $this->add_user_meta($user_id);
                EventM_Notification_Service::user_registration($user_data);
                wp_send_json_success();
            } else {
                wp_send_json_error(array('msg' => $user_id->get_error_message()));
            }
        }
        wp_send_json_error(array('msg' => __('User already exists.', 'eventprime-event-calendar-management')));
    }

    public function verify_user($email) {
        // Assuming both email and username are same
        return (username_exists($email) || email_exists($email));
    }

    private function add_user_meta($user_id) {
        $user = get_user_by('ID', $user_id);
        if ($user) {
            update_user_meta($user_id, 'first_name', event_m_get_param('first_name', true));
            update_user_meta($user_id, 'last_name', event_m_get_param('last_name', true));
            update_user_meta($user_id, 'phone', event_m_get_param('phone', true));
        }
    }

    public function login_user() {
        $user_name = event_m_get_param("user_name", true);
        $password = event_m_get_param("password", true);
        $response = new stdClass();

        $user_id = 0;
        $is_disabled = 1;

        // Check if user exists
        if (username_exists($user_name)) {
            $user = get_user_by('login', $user_name);
            $user_id = $user->ID;
        } elseif (email_exists($user_name)) {
            $user = get_user_by('email', $user_name);
            $user_id = $user->ID;
        } elseif ($user_name == "") {
            $error = new WP_Error('user_not_exists', __('Username cannot be blank.', 'eventprime-event-calendar-management'));
            echo json_encode($error);
            die;
        } elseif ($password == "") {
            $error = new WP_Error('user_not_exists', __('Password cannot be blank.', 'eventprime-event-calendar-management'));
            echo json_encode($error);
            die;
        } else {
            $error = new WP_Error('user_not_exists', __('User does not exists. Please check your details.', 'eventprime-event-calendar-management'));
            echo json_encode($error);
            die;
        }

        $is_disabled = (int) get_user_meta($user_id, 'rm_user_status', true);

        if ($is_disabled) {
            $error = new WP_Error('user_not_exists', __('User is not active yet.', 'eventprime-event-calendar-management'));
            echo json_encode($error);
            die;
        }

        $info['user_login'] = $user->user_login;
        $info['user_password'] = event_m_get_param("password");
        $info['remember'] = true;

        $user_signon = wp_signon($info, false);
        if (is_wp_error($user_signon)) {
            $error = new WP_Error('invalid_user', __('Wrong Username/Email or Password.', 'eventprime-event-calendar-management'));
            echo json_encode($error);
            die;
        } else {
            wp_set_current_user($user_signon->ID);
            $response->success = true;
            echo json_encode($response);
            die;
        }

        die();
    }
}